==> apache-camel-3.4.0-src.zip: apache-camel-3.4.0/core/camel-core/src/test/java/org/apache/camel/issues/RoutingSlipNotStopErrorHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.issues;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.LoggingLevel;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

public class RoutingSlipNotStopErrorHandlerTest extends ContextTestSupport {

    private static final String DIRECT_START = "direct:start";
    private static final String THROWING_ROUTE = "direct:throwingRoute";

    public static class CustomRoutingSlip {

        public String router() {
            return THROWING_ROUTE;
        }
    }

    @Test
    public void testRoutingSlipNotStopErrorHandler() throws Exception {
        getMockEndpoint("mock:result").expectedMessageCount(2);

        template.sendBody(DIRECT_START, "ABC");

        template.sendBody(THROWING_ROUTE, "123");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                errorHandler(deadLetterChannel("mock:result").maximumRedeliveries(1).redeliveryDelay(10).retriesExhaustedLogLevel(LoggingLevel.ERROR)
                    .retryAttemptedLogLevel(LoggingLevel.WARN).logStackTrace(true).logRetryStackTrace(true));

                from(DIRECT_START).routingSlip(method(CustomRoutingSlip.class, "router"));

                from(THROWING_ROUTE).process().exchange(o -> {
                    throw new IllegalStateException();
                });
            }
        };
    }
}

==> apache-camel-4.13.0-src.zip: apache-camel-4.13.0/core/camel-core/src/test/java/org/apache/camel/issues/RoutingSlipNotStopErrorHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.issues;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.LoggingLevel;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

public class RoutingSlipNotStopErrorHandlerTest extends ContextTestSupport {

    private static final String DIRECT_START = "direct:start";
    private static final String THROWING_ROUTE = "direct:throwingRoute";

    public static class CustomRoutingSlip {

        public String router() {
            return THROWING_ROUTE;
        }
    }

    @Test
    public void testRoutingSlipNotStopErrorHandler() throws Exception {
        getMockEndpoint("mock:result").expectedMessageCount(2);

        template.sendBody(DIRECT_START, "ABC");

        template.sendBody(THROWING_ROUTE, "123");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                errorHandler(deadLetterChannel("mock:result").maximumRedeliveries(1).redeliveryDelay(10)
                        .retriesExhaustedLogLevel(LoggingLevel.ERROR)
                        .retryAttemptedLogLevel(LoggingLevel.WARN).logStackTrace(true).logRetryStackTrace(true));

                from(DIRECT_START).routingSlip(method(CustomRoutingSlip.class, "router"));

                from(THROWING_ROUTE).process().exchange(o -> {
                    throw new IllegalStateException();
                });
            }
        };
    }
}
